var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { child1Uid, client, groupUid } from "./helpers.js";
import { GroupType } from "../api.js";
describe("Groups", () => __awaiter(void 0, void 0, void 0, function* () {
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.refreshTestData();
    }));
    it("Groups find", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.groups.find();
        assert.isNotEmpty(result.data);
    }));
    it("Groups create", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.groups.create({
            name: "Test",
            type: GroupType.Dynamic,
            rule: `{"displayName": {"_gt": "A"}}`,
            tags: ["Notifications"],
        });
        assert.equal(result.data.name, "Test");
        assert.equal(result.data.rule, `{"displayName": {"_gt": "A"}}`);
    }));
    it("Groups add member", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.groups.addMember(groupUid, {
            personUid: child1Uid,
        });
        assert.equal(result.data.personUid, child1Uid);
        assert.equal(result.data.groupUid, groupUid);
    }));
    it("Groups find members", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.groups.findMembers(groupUid);
        assert.isNotEmpty(result.data);
    }));
}));
